@@ -16,9 +16,9 @@ const (
 
 func main() {
 	configRules := []*config.Rule{}
-	configRules = append(configRules, rules.AgeSecretKey())
 	configRules = append(configRules, rules.AdobeClientID())
 	configRules = append(configRules, rules.AdobeClientSecret())
+	configRules = append(configRules, rules.AgeSecretKey())
 	configRules = append(configRules, rules.AlibabaAccessKey())
 	configRules = append(configRules, rules.AlibabaSecretKey())
 	configRules = append(configRules, rules.AsanaClientID())
@@ -104,6 +104,9 @@ func main() {
 
 	config := config.Config{
 		Rules: configRules,
+		Allowlist: config.Allowlist{
+			StopWords: rules.DefaultStopWords,
+		},
 	}
 	tmpl, err := template.ParseFiles(templatePath)
 	if err != nil {
