@@ -1,6 +1,7 @@
 package rules
 
 import (
+	"github.com/zricethezav/gitleaks/v8/cmd/generate/secrets"
 	"github.com/zricethezav/gitleaks/v8/config"
 )
 
@@ -9,16 +10,16 @@ func AsanaClientID() *config.Rule {
 	r := config.Rule{
 		Description: "Asana Client ID",
 		RuleID:      "asana-client-id",
-		Regex:       generateSemiGenericRegex([]string{"asana"}, numeric16),
+		Regex:       generateSemiGenericRegex([]string{"asana"}, numeric("16")),
 		SecretGroup: 1,
 		Keywords:    []string{"asana"},
 	}
 
 	// validate
 	tps := []string{
-		"asanaKey := \"" + sampleNumeric16 + "\"",
+		generateSampleSecret("asana", secrets.NewSecret(numeric("16"))),
 	}
-	return validate(r, tps)
+	return validate(r, tps, nil)
 }
 
 func AsanaClientSecret() *config.Rule {
@@ -26,13 +27,13 @@ func AsanaClientSecret() *config.Rule {
 	r := config.Rule{
 		Description: "Asana Client Secret",
 		RuleID:      "asana-client-secret",
-		Regex:       generateSemiGenericRegex([]string{"asana"}, alphaNumeric32),
+		Regex:       generateSemiGenericRegex([]string{"asana"}, alphaNumeric("32")),
 		Keywords:    []string{"asana"},
 	}
 
 	// validate
 	tps := []string{
-		"asanaKey := \"" + sampleAlphaNumeric32Token + "\"",
+		generateSampleSecret("asana", secrets.NewSecret(alphaNumeric("32"))),
 	}
-	return validate(r, tps)
+	return validate(r, tps, nil)
 }
